/*
 *  SokoBan, a Sokoban game.
 *  Copyright (C) 2008  Colomban Wendling <ban@herbesfolles.org>
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef __MAP_H__
#define __MAP_H__


#include <SDL/SDL.h>
#include "sokoban.h"
#include "object.h"


#define MAP_BLOCKSIZE 50
#define MAP_WIDTH  16
#define MAP_HEIGHT 12


typedef enum _Map Map;
enum _Map {
   UNKNOWN = 1<<0, /**< Unknown block */
   WALL    = 1<<1, /**< Block is a wall */
   GROUND  = 1<<2, /**< Block is ground */
   POINT   = 1<<3, /**< Block is an end */
   BOX     = 1<<4, /**< Block is a box badly positioned */
   BOXDONE = 1<<5  /**< Block is a box correctly positioned */
};



#define map_getWidth() MAP_WIDTH
#define map_getHeight() MAP_HEIGHT
#define map_getBlockSize() MAP_BLOCKSIZE


/* I can't refer to enum _MyBool with MyBool typedef
 * What's the fuck!?? */
enum _MyBool map_checkBlockAtPos (int x, int y, int c);
void map_setBlockAtPos (int x, int y, Map v);
void map_set (Map bmap[MAP_HEIGHT][MAP_WIDTH]);
void map_resetToBlock (Map block);
Map map_getBlockAtPos (int x, int y);
void map_blit (SDL_Surface *screen);

void map_blitObject (Object *obj, SDL_Surface *screen);
void map_blitSurfaceAtPos (SDL_Surface *surface, int x, int y,
                           SDL_Surface *screen);
void map_blitSurfaceAtRect (SDL_Surface *surface, SDL_Rect pos,
                            SDL_Surface *screen);


#endif /* guard */
