/*
 *  SokoBan, a Sokoban game.
 *  Copyright (C) 2008  Colomban Wendling <ban@herbesfolles.org>
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef __OBJECT_H__
#define __OBJECT_H__


#include <SDL/SDL.h>

typedef struct _Object Object;

struct _Object
{
   SDL_Surface *surface; /**< the SDL_Surface of the object */
   SDL_Rect     pos;     /**< the SDL_Rect of the object, that contain its
                                                                    position */
};


#define OBJECT(v) (Object*)v


Object* object_new (void);
Object* object_newWithData (SDL_Surface *surface, int x, int y);
Object* object_newWithDataSDL (SDL_Surface *surface, SDL_Rect pos);

void object_free (Object *obj);

Object* object_setSurface (Object *obj, SDL_Surface *surface);
Object* object_setPosX (Object *obj, int x);
Object* object_setPosY (Object *obj, int y);
Object* object_setPos (Object *obj, int x, int y);
Object* object_setPosFromRect (Object *obj, SDL_Rect pos);
Object* object_setData (Object *obj, SDL_Surface *surface, int x, int y);
Object* object_setDataFromSDL (Object *obj, SDL_Surface *surface, SDL_Rect pos);

#define object_getSurface(obj) (obj->surface)
#define object_getPos(obj) (obj->pos)
#define object_getPosX(obj) (obj->pos.x)
#define object_getPosY(obj) (obj->pos.y)

#define object_getSurfaceWidth(obj) object_getSurface (obj)->w
#define object_getSurfaceHeight(obj) object_getSurface (obj)->h
#define object_getSurfaceH(obj) object_getSurfaceHeight (obj)
#define object_getSurfaceW(obj) object_getSurfaceWidth (obj)


#define object_blit(obj, screen) \
   SDL_BlitSurface (object_getSurface (obj), NULL, screen, \
                    &object_getPos (obj))


#endif /* guard */
